% ------------------------------
% Author: Filippo Ferroni, UPF.
% Date  : 7-12-2008
% ------------------------------

% MAIN.m is the main program.
% The program loads the data and calls the RWM algorithm to compute the
% posterior distributions under different settings. Output is stored in the
% folder .\POSTERIOR\output.
% I conseder two types of estimation approaches: two step, where data are
% first filtered and then DSGE structural parameters are estimated, and one
% step, where structural and filtering parameters are jointly estimated
nomi.est  = strvcat('2s','1s');
% I consider three filters: linear detrending, HP filter and first
% difference.
nomi.filt = strvcat('lt','hp','fd');
% Thus, we have 6 setpus.

% Variance for the RWM algorithm; this value represent the step for the RWM
% algorithm to moove around in the parameter space.
% This value has to be tuned to get a 25-40% acceptance rate and according 
% to the type of estimation that we do, 2 steps, hp-dsge, lt-dsge or fd-dsge
ka      = [70, 50, 50, 170, 25, 25];
 
% Load the data. The data is in log and raw. Data contains the log of per
% capita GDP, hours worked, real wages and inflation from 01/01/64 to
% 01/04/07. For detail on data construction, see .\database\readingdata.m.
load .\database\data

% Preparing the data for the two step estimates. Data filtered in different
% way will be collected in a matrix 174x4x3, 'DATA'. The fist dimension
% refers to the number of observations, the second dimension to the unmber
% of times series, and the third to the type of filter.
[T,fil]=size(data);
DATA  =zeros(T,fil,3);

% LT FILTER:
T = 1:1:length(data);
X = [ones(length(data),1), T'];
for i=1:size(data,2)
    DATA(:,i,1) = data(:,i) - X*(X'*X)^-1*X'*data(:,i);
    beta(:,i)   = (X'*X)^-1*X'*data(:,i);
end
% HP FILTER:
DATA(:,:,2) = data-hpfilter(data,1600);
% FD FILTER:
fd = data(2:end,:) - data(1:end-1,:);
DATA(2:end,:,3) = fd - kron(mean(fd),ones(length(data)-1,1));

% If you want to see the filtered data, set filtdataplot='yes'.
filtdataplot='no';
dataplot;

% 'N' is the number of iterations of the RWM algorithm. A 'safe' number of
% repetition is 1 million draws; that ensures convergence for all the
% parameters. It takes about 4-5 hours for each setups. If you want to see 
% how the program works, 200,000 draws are fine, but there might be 
% parameters that do not converge. Advise on the selection of N: use only 
% multiple of 100,000, it may matter at time of computing the posterior
% distributions (for 'burn in' draws and removing the correlation among draws). 
% For each setting (two step-hp filter, two step-lt filter, .... , one step
% - fd filter [6 in total]), the program calls the RWM algorithm, 'RWM.m'. 
% For details on the RWM algortim see 'RWM.m'.

% The set of structural parameters except standard deviations. 
para.struct = strvcat('\sigma_c','\sigma_n','\rho_r','\rho_{\pi}',...
    '\rho_{y}','\zeta_p','\rho_{\chi}','\rho_{z}'); 
struct=size(para.struct,1);

N=1000000;
for e=1:2          % 'e' refers to the type of estimate, one or two step
    for filo=1:3   % 'filo' refers to the filter.
        k=ka(3*(e-1)+filo);
        if strcmp(nomi.est(e,:),'2s')==1,
            dy=DATA(:,:,filo);
            if filo==3
                dy=DATA(2:end,:,filo);   
            end
            run('RWM');
            display('FINE giro')
            display(num2str(nomi.est(e,:)))
            display(num2str(nomi.filt(filo,:)))      
        else
            dy=data;
            run('RWM');
            display('FINE giro')
            display(num2str(nomi.est(e,:)))
            display(num2str(nomi.filt(filo,:)))
        end
    end
end
display('FINE !!!!!!')

