% ------------------------------
% Author: Filippo Ferroni, UPF.
% Date  : 7-12-2008
% ------------------------------

% POdds computes the Posterior Odds of different specifications. The 
% Posterior Odds (PO) is the ratio of predictive density of the data 
% conditional on the DSGE model and a filter specification with respect to 
% the linear detrending one. The predictive density of the data conditional 
% on the DSGE model and on the filter specification is computed as the 
% average of the sum of the log likelihood and log prior for all the 
% accepted draws. The program computes the PO and creates a \LaTeX table, 
% which is saved in a .txt file in \verb".\POSTEIOR\tables"

nomi.est  = strvcat('2s','1s');
nomi.filt = strvcat('lt','hp','fd');

w1s=zeros(3,1);

e=2;
for filo=1:size(nomi.filt,1)
    load(['.\output\' num2str(nomi.est(e,:)) '_output_' ...
        num2str(nomi.filt(filo,:)) '.mat'],'loglike_p','logprior_p');
    w1s(filo)=mean(loglike_p+logprior_p);   
end

PO  = w1s - w1s(1);   % with respect to linear detrending
 
fid01=fopen('.\table\PO.txt','w');
fprintf(fid01,'%s\r ','\begin{table}');
fprintf(fid01,'%s\r ','\centering');
fprintf(fid01,'%s\r ','\begin{tabular}{c|ccc}');
fprintf(fid01,'%s\r ','& lt-dsge & hp-dsge & fd-dsge\\');
fprintf(fid01,'%s\r ','\hline');
fprintf(fid01,'%s\r ','\hline');
fprintf(fid01,'%s\r ','$g(\mathcal{F}_j)$ & 1/3  & 1/3  & 1/3 \\');
fprintf(fid01,'%s ','$\ln p(y|\mathcal{M},\mathcal{F}_j)$');
for i=1:3
    fprintf(fid01,'%s ','&');
    fprintf(fid01,'%6.0f',w1s(i));
end
fprintf(fid01,'%s\r ','\\');
fprintf(fid01,'%s ','$\ln(PO)$ w.r.t lt-dsge');
for i=1:3
    fprintf(fid01,'%s ','&');
    fprintf(fid01,'%6.2f',PO(i));
end
fprintf(fid01,'%s\r ','\\');
fprintf(fid01,'%s\r ','\hline');
fprintf(fid01,'%s\r ','\hline');
fprintf(fid01,'%s\r ','\end{tabular}');
fprintf(fid01,'%s\r ','\caption{Marginal Likelihood, Posterior Odds}');
fprintf(fid01,'%s\r ','\label{likes}');
fprintf(fid01,'%s\r ','\end{table}');
fclose(fid01);
clear all