% ------------------------------
% Author: Filippo Ferroni, UPF.
% Date  : 7-12-2008
% ------------------------------

% POSTERIOR.m is the program that produces the graphs of the CUMSUM 
% statistics and of the prior-postrior distributions for each parameters
% for a given estimation setup.

if strcmp(nomi.est(e,:),'2s')==1,
    nomi.rnames = strvcat('\sigma_c','\sigma_n','\rho_r','\rho_{\pi}','\rho_{y}',...
    '\zeta_p','\rho_{\chi}','\rho_{z}','\sigma_{\chi}','\sigma_{z}',...
    '\sigma_{mp}', '\sigma_{\mu}'); 

elseif strcmp(nomi.est(e,:),'1s')==1 && strcmp(nomi.filt(filo,:),'hp')==1,
    nomi.rnames = strvcat('\sigma_c','\sigma_n','\rho_r','\rho_{\pi}','\rho_{y}',...
    '\zeta_p','\rho_{\chi}','\rho_{z}','\sigma_{\chi}','\sigma_{z}',...
    '\sigma_{mp}', '\sigma_{\mu}', '\sigma_y^{\zeta}', '\sigma_n^{\zeta}', ...
    '\sigma_{\omega}^{\zeta}', '\sigma_{\pi}^{\zeta}'); 

elseif strcmp(nomi.est(e,:),'1s')==1 && strcmp(nomi.filt(filo,:),'lt')==1,
    nomi.rnames = strvcat('\sigma_c','\sigma_n','\rho_r','\rho_{\pi}','\rho_{y}',...
    '\zeta_p','\rho_{\chi}','\rho_{z}','\sigma_{\chi}','\sigma_{z}',...
    '\sigma_{mp}', '\sigma_{\mu}', '\sigma_y^{\eta}', '\sigma_n^{\eta}', ...
    '\sigma_{\omega}^{\eta}', '\sigma_{\pi}^{\eta}',...
    'B_y','B_n','B_{\omega}', 'B_{\pi}'); 
else
    nomi.rnames = strvcat('\sigma_c','\sigma_n','\rho_r','\rho_{\pi}','\rho_{y}',...
    '\zeta_p','\rho_{\chi}','\rho_{z}','\sigma_{\chi}','\sigma_{z}',...
    '\sigma_{mp}', '\sigma_{\mu}', '\sigma_y^{\eta}', '\sigma_n^{\eta}', ...
    '\sigma_{\omega}^{\eta}', '\sigma_{\pi}^{\eta}',...
    '\gamma_{y}', '\gamma_{n}', '\gamma_{\omega}', '\gamma_{\pi}'); 
end

fil=size(data,2);

% Set extension of the figure that you want to save. 
% If you want to save them as matlab figure set: 
ext  = 'fig'; 
type = 'fig';
% If you want to save them as eps figure set: 
% ext  = 'eps';
% type = 'psc2';

%--------------------------------------------------------------------------
% Marginal Likeliood: 
 
figure(filo+e)
plot(loglike_p(100:end));
saveas(gcf,['.\graphs\like_' num2str(nomi.est(e,:)) '_'...
    num2str(nomi.filt(filo,:)) '.'   num2str(ext)],num2str(type))

close all
clear loglike_p

%--------------------------------------------------------------------------
% Convergence Checks:
 
theta_r     =  theta_p(0.4*N+1:end,:);
[No,largo]  =  size(theta_r);
 
NN=kron([1:1:No],ones(largo,1))';
cumsum_r= cumsum(theta_r);
CUMSUM=(cumsum_r-kron(mean(theta_r),ones(No,1)))./kron(std(theta_r),ones(No,1))./NN;
clear NN cumsum_r theta_r No
 
% STRUCTURAL PARAMETERS and STANDARD DEVIATIONS of DSGE MODEL
figure(filo+e*10)
for i=1:struct
    subplot(3,4,i)
    plot(CUMSUM(:,i),'LineWidth',2); hold on;
    title(nomi.rnames(i,:))
    axis tight
end
saveas(gcf,['.\graphs\Convergence_S_' num2str(nomi.est(e,:)) '_' ...
    num2str(nomi.filt(filo,:)) '.'   num2str(ext)],num2str(type))
 
% FILTERING PARAMETERS 
if largo>struct,
    figure(filo+e*10+1)
    for i=1:largo-struct
       subplot(3,3,i)
       plot(CUMSUM(:,struct+i),'LineWidth',2); hold on;
       title(nomi.rnames(struct+i,:))
       axis tight
    end
    saveas(gcf,['.\graphs\Convergence_F_' num2str(nomi.est(e,:)) '_' ...
        num2str(nomi.filt(filo,:))  '.'   num2str(ext)],num2str(type))
end
clear CUMSUM

%--------------------------------------------------------------------------
% Prior and Posterior Plots:

% We need to reduce the dimesionality of theta_p for two reason. First, if
% you have set 1 millon draws, then it gets computationally too demanding. 
% Second, we need to remove the correlation across draws by selecting 
% randomply one every ELLE draws. With 1,000,000 iteration ELLE should be 
% set to 1000. As I metioned before, with one million iteration we get 
% convergence for all the parameters after 500,000 draws, thus we remove 
% the first half of the chain. 

burnin     =  0.5*N;
ELLE       =  1000;

% Removing the correlation between draws, I throw the first 'burnin' draws 
% and keep one every 'ELLE':
Theta_s     = apiter(theta_p,burnin,ELLE);

% Drawing from the priors. About the prior assumption see prior.m file.
GG         =  length(Theta_s);
Priors     =  zeros(GG,largo);

% STRUCTURAL PARAMETERS and STANDARD DEVIATIONS of DSGE MODEL
Priors(:,1)  = gamrnd(20,0.1,GG,1);     % elasticity of consumption
Priors(:,2)  = gamrnd(30,0.1,GG,1);     % elasticity of labor
Priors(:,3)  = betarnd(8,6,GG,1);       % autoregressive parameter in monetary policy rule
Priors(:,4)  = normrnd(1.5,0.1,GG,1);   % response to inflation in monetary policy rule
Priors(:,5)  = normrnd(.4,0.1,GG,1);    % response to inflation in monetary policy rule  
Priors(:,6)  = betarnd(10,8,GG,1);      % probability of keeping the price fixed
Priors(:,7)  = betarnd(18,8,GG,1);      % AR(1) in the preference process
Priors(:,8)  = betarnd(18,8,GG,1);      % AR(1) in the technology process
% DSGE MODEL SHOCKS STANDARD DEVIATIONS
for j=1:4
    Priors(:,8+j) = 1./gamrnd(10,20,GG,1);
end

% FILTERING PARAMETERS 
if largo>struct,
    if strcmp(nomi.filt(filo,:),'hp')==1,
        for j=1:fil
           Priors(:,struct+j) = 1./gamrnd(10,20,GG,1);
        end
    elseif strcmp(nomi.filt(filo,:),'lt')==1,
        for j=1:fil
           Priors(:,struct+j) = 1./gamrnd(10,20,GG,1);
        end
        for j=1:fil
           Priors(:,16+j) = normrnd(0,0.001,GG,1);
        end
    else
        for j=1:fil
           Priors(:,struct+j) = 1./gamrnd(10,20,GG,1);
        end
        for j=1:fil
           Priors(:,16+j) = normrnd(0,0.09,GG,1);
        end
    end
end


% STRUCTURAL:
figure(filo+100*e)
for i=1:struct
    subplot(3,4,i)
    [g,y]=ksdensity(Priors(:,i));
    plot(y,g,'g-.','LineWidth',2)
    hold on
    [f,x,u] = ksdensity(Theta_s(:,i));
    [f,x] = ksdensity(Theta_s(:,i),'width',5*u);
    plot(x,f,'LineWidth',2);
    hold on; title(nomi.rnames(i,:));
    xlim([min([x,y]),max([x,y])]);
    hold off
end
saveas(gcf,['.\graphs\Posteriors_S_' num2str(nomi.est(e,:)) '_'...
     num2str(nomi.filt(filo,:)) '.'   num2str(ext)],num2str(type))
close all

% FILTERING:
if strcmp(nomi.est(e,:),'1s')==1 && strcmp(nomi.filt(filo,:),'hp')==1, 
    figure(filo+100*e)
    for i=1:fil
       subplot(2,4,i)
       [g,y,v]=ksdensity(Priors(:,i+struct));
       [g,y] = ksdensity(Priors(:,i+struct),'width',10*v);
       plot(y,g,'g-.','LineWidth',2)
       hold on
       [f,x,u] = ksdensity(Theta_s(:,i+struct));
       [f,x] = ksdensity(Theta_s(:,i+struct),'width',8*u);
       plot(x,f,'LineWidth',2);
       hold on; title(nomi.rnames(i+struct,:));
       xlim([min([x,y]),max([x,y])]);
       hold off
    end
    saveas(gcf,['.\graphs\Posteriors_F_' num2str(nomi.est(e,:)) '_'...
       num2str(nomi.filt(filo,:)) '.'   num2str(ext)],num2str(type))

elseif (strcmp(nomi.est(e,:),'1s')==1 && strcmp(nomi.filt(filo,:),'lt')==1)
    for i=1:fil*2
       subplot(2,4,i)
       [g,y]=ksdensity(Priors(:,i+struct));
        plot(y,g,'g-.','LineWidth',2)
        hold on
        [f,x,u] = ksdensity(Theta_s(:,i+struct));
        [f,x] = ksdensity(Theta_s(:,i+struct),'width',30*u);
        plot(x,f,'LineWidth',2);
        hold on; title(nomi.rnames(i+struct,:));
        xlim([min([x,y]),max([x,y])]);
        hold off
    end
    saveas(gcf,['.\graphs\Posteriors_F_' num2str(nomi.est(e,:)) '_'...
       num2str(nomi.filt(filo,:)) '.'   num2str(ext)],num2str(type))
elseif  (strcmp(nomi.est(e,:),'1s')==1 && strcmp(nomi.filt(filo,:),'fd')==1)
    for i=1:fil*2
       subplot(2,4,i)
       [g,y]=ksdensity(Priors(:,i+struct));
        plot(y,g,'g-.','LineWidth',2)
        hold on
        [f,x,u] = ksdensity(Theta_s(:,i+struct));
        [f,x] = ksdensity(Theta_s(:,i+struct),'width',30*u);
        plot(x,f,'LineWidth',2);
        hold on; title(nomi.rnames(i+struct,:));
        xlim([min([x,y]),max([x,y])]);
        hold off
    end
    saveas(gcf,['.\graphs\Posteriors_F_' num2str(nomi.est(e,:)) '_'...
       num2str(nomi.filt(filo,:)) '.'   num2str(ext)],num2str(type))
end
close all