% ------------------------------
% Author: Filippo Ferroni, UPF.
% Date  : 7-12-2008
% ------------------------------

% TABLE.m is the main program that computes the posterior statistics for
% each setups.  
% We conseder two types of estimation approaches: two step, where data are
% first filtered and then DSGE structural parameters are estimated, and one
% step, where structural and filtering parameters are jointly estimated
nomi.est  = strvcat('2s','1s');
% Consider three filters: linear detrending, HP filter and first
% difference.
nomi.filt = strvcat('lt','hp','fd');
% Thus, we have 6 different setups. The output (theta_jj_ii.mat where 
% ii= 2s or 1s, and jj= 'lt','hp','fd') are stored in the folder 
% .\POSTERIOR\table. 

% We consider one every ELLE draws for two reasons. First, we need to reduce
% the dimesionality of theta_p if we want to sort them. Second, by picking
% randomply one every ELLE draws we reduce the correlation among draws.
% For N=1,000,000 set ELLE=100.

ELLE=100;

for e=1:size(nomi.est,1)
    for filo=1:size(nomi.filt,1)
        load(['.\output\' num2str(nomi.est(e,:)) '_output_' ...
             num2str(nomi.filt(filo,:)) '.mat'],'theta_p','N')
        [N,largo]  = size(theta_p);
        stat       =  zeros(5,largo);
        stat(1,:)  =  mean(theta_p);
        stat(3,:)  =  std(theta_p);
        theta_q    =  apiter(theta_p,0.2*N,ELLE);
        theta_sort =  sort(theta_q);
        [No,largo] = size(theta_q);
        stat(2,:)  =  theta_sort(No/2,:);
        stat(4,:)  =  theta_sort(No*0.95,:);
        stat(5,:)  =  theta_sort(No*0.05,:);
        clear theta_sort theta_p theta_q
        stat       =  stat';
        save(['.\table\stat_' num2str(nomi.est(e,:)) '_'...
            num2str(nomi.filt(filo,:)) '.mat'], 'stat');
    end
end

clear all