% ------------------------------
% Author: Filippo Ferroni, UPF.
% Date  : 7-12-2008
% ------------------------------

% READINGDATA.m loads and saves the data in .mat file from a excel file.
% The data are colelcted in a excel file called 'DATA.xls'. All the times
% seres are downloaded from the Federal Reserve Bank of St. Louis.

% Everithing starts from 01/01/64

[DATA] = xlsread('DATA');

y      = DATA(:,1);        % real gdp (billions of chained $)
W      = DATA(:,2);       % compensation of employees: wages and salary (billions of $)
pce    = DATA(:,3);       % Price Consuption Expenditure: Chain-type Price Index 
hour_w = DATA(:,4);       % AVERAGE WEEKLY HOURS OF PRODUCTION WORKERS
empl   = DATA(:,5);       % ALL EMPLOYEES (Thousand)
pop    = DATA(:,6);       % Total Population: All Ages including Armed Forces Overseas (Thousand)

% real per capita gdp:
y=y./pop;

% real wage:
w=W./pce./pop; 

% HOUR WORKED:
% Normalization of the weekly hour worked. 
% AVERAGE WEEKLY HOURS OF PRODUCTION WORKERS divided by the numer of hour in a week.
hour=hour_w/(24*7);

% To abtain a proxy for hour worked we multiply the latter times the ratio
% between the total employees and total population:
n=hour.*(empl./pop);

% INFLATION: Since we have monthly observations, we discard two every three
% observations:
[pprezzi] = xlsread('ppi');
for m=1:floor(length(pprezzi)/3)
    prez(m)=pprezzi((m-1)*3+1);
end
pi=prez(2:end)./prez(1:end-1);

data  = [log(y), log(n), log(w), log(pi')];
save data.mat data
clear all;