function [theta]=initialvalues(data,x)

% ------------------------------
% Author: Filippo Ferroni, UPF.
% Date  : 7-12-2008
% ------------------------------

% INITIALVALUES give the starting point of the algorithm RWM. Input is the
% string value for x, which stands for the trend specification and could be
% either 'lt', either 'hp' or 'fd'. The initial values of the structural 
% parameters are the same across trend specifications.
% Input  : - the set of times series, 'data'.
%          - the type of estimate, 'x', which could be '2s','lt','hp' or  
%            'fd'. Where 2 steps = '2s', hp-dsge = 'hp', lt-dsge = 'lt' and  
%            fd-dsge = 'fd'.   
% Output : the initial value for the parameters to start the
% Metropolis-Hastings recursion, 'theta'.
  
[T,fil]=size(data);

% STRUCTURAL PARAMETERS of DSGE MODEL
theta(1)=1;      % elasticity of consumption
theta(2)=1;      % elasticity of labor
theta(3)=0.6;    % autoregressive parameter in monetary policy rule  
theta(4)=1.5;    % response to inflation in monetary policy rule  
theta(5)=0.2;    % response to output in monetary policy rule  
theta(6)=0.8;    % probability of keeping the price fixed
theta(7)=0.4;    % AR(1) in the preference process
theta(8)=0.4;    % AR(1) in the technology process

% DSGE MODEL SHOCKS STANDARD DEVIATIONS
theta(9) =0.01;      % s.d. of preference
theta(10)=0.01;      % s.d. of techn
theta(11)=0.01;      % s.d. of monetary policy
theta(12)=0.01;      % s.d. of markup 

% FILTERING PARAMETERS 
% The number of parameters depends on the number of times series we are
% considering. In this setup, we have 4 observable variables, y n w and pi,
% thus for the 'hp' we have 4 parameters, and 8 for 'fd' and 'lt'.
 
if strcmp(x,'hp')==1,
    % trend shocks standard devations
    for f1=1:fil
        theta(12+f1)=0.0005;
    end  
elseif strcmp(x,'lt')==1,
    % trend shocks standard devations
    for f=1:fil
        theta(12+f)=0.0035;    
    end
    % Coefficients on the linear trend specifications. b, slope. A good 
    % guess for the initial value of the slope is the OLS estimator.
    X=[ones(T,1), [1:T]'];
    for f=1:fil, 
        beta(:,f)=(X'*X)^-1*X'*data(1:end,f); 
        theta(12+fil+f)=beta(2,f); 
    end
elseif strcmp(x,'fd')==1,
    % trend shocks standard devations
    for f=1:fil
        theta(12+f)=0.003;    
    end
    % coefficients on the first difference specifications
    % gamma, constant. A good guess for the initial value of the constrant 
    % is the sample mean.
    Gamma = eye(fil);
    % Since inflation is already stationary we do not need to take first
    % difference. Given that inflation is in the sixth column, I do not take first 
    % difference on the fourth column.
    Gamma(4,4) = 0;
    mdata = mean(data(2:end,:) - data(1:end-1,:)*Gamma);
    for ff=1:fil,  
        theta(12+fil+ff)=mdata(ff);     
    end
end
