function [p]=prior(data,theta,x)

% ------------------------------
% Author: Filippo Ferroni, UPF.
% Date  : 7-12-2008
% ------------------------------

% PRIOR computes the prior evaluated at a certain value for the parameters
% theta, for a particular type of estimation, two step, lt-dsge, hp-dsge or
% fd-dsge
% Input  : - a value for the parameters, 'theta' 
%          - the type of estimate, 'x', which could be '2s', 'lt','hp'  
%            or 'fd'. Where 2 steps = '2s', hp-dsge = 'hp', lt-dsge = 'lt' and  
%            fd-dsge='fd'.
% Output : the log of the prior, 'p'

p=0;

[T,fil]=size(data);

% STRUCTURAL PARAMETERS of DSGE MODEL
p=log(gampdf(theta(1),20,0.1))+p;        % elasticity of consumption
p=log(gampdf(theta(2),30,0.1))+p;        % elasticity of labor
p=log(betapdf(theta(3),8,6))+p;          % autoregressive parameter in monetary policy rule
p=log(normpdf(theta(4),1.5,0.1))+p;      % response to inflation in monetary policy rule  
p=log(normpdf(theta(5),0.4,0.1))+p;      % response to inflation in monetary policy rule  
p=log(betapdf(theta(6),10,8))+p;         % probability of keeping the price fixed
p=log(betapdf(theta(7),18,8))+p;         % AR(1) in the preference process
p=log(betapdf(theta(8),18,8))+p;         % AR(1) in the technology process

% DSGE MODEL SHOCKS STANDARD DEVIATIONS
for j=1:4
    p=log(gampdf(1./theta(8+j),10,20))+p;       %  structural shocks
end

% FILTERING PARAMETERS 
% The number of filtering parameters depends on the number of times series we are
% considering. In this setup, we have 4 observable variables, y n w and pi,
% thus for the 'hp' we have 4 parameters, and 8 for 'fd' and 'lt'.

if strcmp(x,'hp'),
    % trend shocks standard devations
    for j=1:fil
        p=log(gampdf(1./theta(12+j),10,20))+p;       
    end
    
elseif strcmp(x,'lt'),
    % Trend shocks standard devations
    for j=1:fil
        p=log(gampdf(1./theta(12+j),10,20))+p;        
    end
    % Coefficients on the linear trend specifications. b, slope.
    for j=1:fil
        p=log(normpdf(theta(12+fil+j),0,0.001))+p;              
    end
    
elseif strcmp(x,'fd'),
    % Trend shocks standard devations
    for j=1:fil
        p=log(gampdf(1./theta(12+j),10,20))+p;               
    end
    % Coefficients on the first difference specifications, gamma, constant.
    for j=1:fil
        p=log(normpdf(theta(12+fil+j),0,0.09))+p;              
    end
end