function [VAR]=var_rwm(data,k,x)

% VAR_RWM sets the variance of the RWM algorithm

% Input  : - the set of times series, 'data'.
%          - a scaling parameter, 'k'. This value is set in MAIN.m 
%          - the type of estimate, 'x', which could be '2s', 'lt','hp'  
%          or 'fd'. Where 2 steps = '2s', hp-dsge = 'hp', lt-dsge = 'lt' and  
%          fd-dsge='fd'.
% Output : variance for the RWM algorithm, 'VAR'

[T,fil]=size(data);      % fil is the number of observable variables

% STRUCTURAL PARAMETERS of DSGE MODEL
VAR(1)=0.5;  
VAR(2)=0.5;  
VAR(3)=0.1;
VAR(4)=0.1;
VAR(5)=0.1;
VAR(6)=0.1;
VAR(7)=0.1;
VAR(8)=0.1;

if strcmp(x,'2s')==1,
%   DSGE MODEL SHOCKS STANDARD DEVIATIONS
    for j=1:4
        VAR(8+j)=0.02; %
    end
    
% FILTERING PARAMETERS 
% The number of parameters depends on the number of times series we are
% considering. In this setup, we have 4 observable variables, y n w and pi,
% thus for the 'hp' we have 4 parameters, and 8 for 'fd' and 'lt'.

elseif strcmp(x,'hp')==1,
%   DSGE MODEL SHOCKS STANDARD DEVIATIONS
    for j=1:fil
        VAR(8+j)=0.01; %
    end
    % Trend standard deviations
    for j=1:fil
        VAR(12+j)=0.008; %
    end
    
elseif strcmp(x,'lt')==1,
%   DSGE MODEL SHOCKS STANDARD DEVIATIONS
    for j=1:fil
        VAR(8+j)=0.01; %
    end
    % Trend standard deviations
    for j=1:fil
        VAR(8+fil+j)=0.005;
    end
    % Coefficients on the linear trend specifications. b, slope.
    for w=1:fil
        VAR(8+fil+fil+w)=0.0035;
    end
elseif strcmp(x,'fd')==1,
%   DSGE MODEL SHOCKS STANDARD DEVIATIONS
    for j=1:fil
        VAR(8+j)=0.01; %
    end
    % Trend standard deviations
    for j=1:fil
        VAR(8+fil+j)=0.008;
    end
    % Constant in the unit root spacificaiton. gamma, drift.
    for w=1:fil
        VAR(8+fil+fil+w)=0.009;
    end    
end

VAR=VAR/k;